
package com.redxun.knowledge.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.redxun.common.base.db.BaseDao;
import com.redxun.common.base.db.BaseService;
import com.redxun.common.base.search.QueryFilter;
import com.redxun.common.model.JPaasUser;
import com.redxun.common.tool.IdGenerator;
import com.redxun.common.service.impl.SuperServiceImpl;
import com.redxun.common.tool.StringUtils;
import com.redxun.knowledge.common.UserService;
import com.redxun.knowledge.entity.dao.Knowledge;
import com.redxun.knowledge.entity.dao.KnowledgeLabel;
import com.redxun.knowledge.entity.vo.BannerAdminVo;
import com.redxun.knowledge.entity.vo.KnowledgeLabelVo;
import com.redxun.knowledge.mapper.KnowledgeLabelMapper;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.*;
import javax.annotation.Resource;

/**
 * [业务--知识标签表]业务服务类
 */
@Service
public class KnowledgeLabelServiceImpl extends SuperServiceImpl<KnowledgeLabelMapper, KnowledgeLabel> implements BaseService<KnowledgeLabel> {

    @Resource
    private UserService userService;

    @Resource
    private KnowledgeLabelMapper knowledgeLabelMapper;

    @Override
    public BaseDao<KnowledgeLabel> getRepository() {
        return knowledgeLabelMapper;
    }

    /**
     * 新增/修改标签数据
     *
     * @param id   标签ID
     * @param name 标签名称
     * @param sort 标签排序
     * @return
     */
    @Transactional(rollbackFor = Exception.class)
    public KnowledgeLabel saveOrUpdateTags(String id, String name, Integer sort) {
        KnowledgeLabel knowledgeLabel = new KnowledgeLabel();
        if (StringUtils.isEmpty(id)) {
            knowledgeLabel.setPkId(IdGenerator.getIdStr());
            knowledgeLabel.setCreateBy(userService.queryLoginUser());
            knowledgeLabel.setCreateTime(new Date());
        } else {
            knowledgeLabel.setPkId(id);
            knowledgeLabel.setUpdateBy(userService.queryLoginUser());
            knowledgeLabel.setCreateTime(new Date());
        }
        knowledgeLabel.setName(name);
        knowledgeLabel.setSort(sort);
        // 更新sort
        knowledgeLabelMapper.adjustSort(sort);
        if (saveOrUpdate(knowledgeLabel)) {
            return knowledgeLabelMapper.selectById(knowledgeLabel.getPkId());
        }

        return null;
    }

    public IPage<KnowledgeLabelVo> findAllTags(QueryFilter filter) {
        IPage<KnowledgeLabelVo> page = knowledgeLabelMapper.findAllTags(filter.getPage(), filter.getParams());
        List<KnowledgeLabelVo> knowledgeLabelVos = page.getRecords();
        knowledgeLabelVos.forEach(e -> {
            JPaasUser user = userService.queryUser(e.getOperator());
            if (user != null) {
                e.setOperatorName(user.getFullName());
            }
        });

        return page;
    }
}
